@@ -220,10 +220,6 @@ def processDialogs():
                 if re.search("\.words$",f) is not None:
                     wordFiles.append(f)
         for f in wordFiles:
-            #if f == last:
-            #    check = 1
-            #if check == 1:
-            updatelogfile(logfilename,f)
             reorganize(path,f,d)
 
 
