@@ -40,7 +40,7 @@ def loadFile(path,cols=None):
         lines = []
         for l in f:
             if head is None:
-                head = l.strip().spilt("\t")
+                head = l.strip().split("\t")
                 continue
             line = l.strip().split("\t")
             newline = { h: line[i] for i,h in enumerate(head) if cols is None or h in cols}
